==> boost-histogram-0.5.0.tar.gz: boost-histogram-0.5.0/src/register_histograms.cpp <==
// Copyright 2018-2019 Henry Schreiner and Hans Dembinski
//
// Distributed under the 3-Clause BSD License.  See accompanying
// file LICENSE or https://github.com/scikit-hep/boost-histogram for details.

#include <boost/histogram/python/pybind11.hpp>

#include <boost/histogram/python/axis.hpp>
#include <boost/histogram/python/histogram.hpp>
#include <boost/histogram/python/register_histogram.hpp>
#include <boost/histogram/python/storage.hpp>
#include <boost/histogram/storage_adaptor.hpp>

void register_histograms(py::module &hist) {
    hist.attr("_axes_limit") = BOOST_HISTOGRAM_DETAIL_AXES_LIMIT;

    register_histogram<vector_axis_variant, storage::int_>(
        hist,
        "_any_int",
        "N-dimensional histogram for unlimited size data with any axis types.");

    register_histogram<vector_axis_variant, storage::unlimited>(
        hist,
        "_any_unlimited",
        "N-dimensional histogram for unlimited size data with any axis types.");

    register_histogram<vector_axis_variant, storage::double_>(
        hist,
        "_any_double",
        "N-dimensional histogram for real-valued data with weights with any axis "
        "types.");

    register_histogram<vector_axis_variant, storage::atomic_int>(
        hist,
        "_any_atomic_int",
        "N-dimensional histogram for threadsafe integer data with any axis types.");

    register_histogram<vector_axis_variant, storage::weight>(
        hist,
        "_any_weight",
        "N-dimensional histogram for weighted data with any axis types.");

    register_histogram<vector_axis_variant, storage::mean>(
        hist,
        "_any_mean",
        "N-dimensional histogram for sampled data with any axis types.");

    register_histogram<vector_axis_variant, storage::weighted_mean>(
        hist,
        "_any_weighted_mean",
        "N-dimensional histogram for weighted and sampled data with any axis types.");
}

==> boost-histogram-0.6.1.tar.gz: boost-histogram-0.6.1/src/register_histograms.cpp <==
// Copyright 2018-2019 Henry Schreiner and Hans Dembinski
//
// Distributed under the 3-Clause BSD License.  See accompanying
// file LICENSE or https://github.com/scikit-hep/boost-histogram for details.

#include "pybind11.hpp"

#include "axis.hpp"
#include "histogram.hpp"
#include "register_histogram.hpp"
#include "storage.hpp"
#include <boost/histogram/storage_adaptor.hpp>

void register_histograms(py::module& hist) {
    hist.attr("_axes_limit") = BOOST_HISTOGRAM_DETAIL_AXES_LIMIT;

    register_histogram<storage::int64>(
        hist,
        "any_int64",
        "N-dimensional histogram for unlimited size data with any axis types.");

    register_histogram<storage::unlimited>(
        hist,
        "any_unlimited",
        "N-dimensional histogram for unlimited size data with any axis types.");

    register_histogram<storage::double_>(
        hist,
        "any_double",
        "N-dimensional histogram for real-valued data with weights with any axis "
        "types.");

    register_histogram<storage::atomic_int64>(
        hist,
        "any_atomic_int64",
        "N-dimensional histogram for threadsafe integer data with any axis types.");

    register_histogram<storage::weight>(
        hist,
        "any_weight",
        "N-dimensional histogram for weighted data with any axis types.");

    register_histogram<storage::mean>(
        hist,
        "any_mean",
        "N-dimensional histogram for sampled data with any axis types.");

    register_histogram<storage::weighted_mean>(
        hist,
        "any_weighted_mean",
        "N-dimensional histogram for weighted and sampled data with any axis types.");
}
